DescribeReportCreationOutput class

Constructors

DescribeReportCreationOutput({String? errorMessage, String? s3Location, String? status})
DescribeReportCreationOutput.fromJson(Map<String, dynamic> json)
factory

Properties

errorMessage → String?
Details of the common errors that all operations return.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Location → String?
The path to the Amazon S3 bucket where the report was stored on creation.
final
status → String?
Reports the status of the operation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited