GetResourcesOutput class

Constructors

GetResourcesOutput({String? paginationToken, List<ResourceTagMapping>? resourceTagMappingList})
GetResourcesOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
paginationToken → String?
A string that indicates that the response contains more data than can be returned in a single response. To receive additional data, specify this string for the PaginationToken value in a subsequent request.
final
resourceTagMappingList → List<ResourceTagMapping>?
A list of resource ARNs and the tags (keys and values) associated with each.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited