ResourceTagMapping class

A list of resource ARNs and the tags (keys and values) that are associated with each.

Constructors

ResourceTagMapping({ComplianceDetails? complianceDetails, String? resourceARN, List<Tag>? tags})
ResourceTagMapping.fromJson(Map<String, dynamic> json)
factory

Properties

complianceDetails → ComplianceDetails?
Information that shows whether a resource is compliant with the effective tag policy, including details on any noncompliant tag keys.
final
hashCode → int
The hash code for this object.
no setterinherited
resourceARN → String?
The ARN of the resource.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
The tags that have been applied to one or more AWS resources.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited