Summary class

A count of noncompliant resources.

Constructors

Summary({String? lastUpdated, int? nonCompliantResources, String? region, String? resourceType, String? targetId, TargetIdType? targetIdType})
Summary.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastUpdated → String?
The timestamp that shows when this summary was generated in this Region.
final
nonCompliantResources → int?
The count of noncompliant resources.
final
region → String?
The AWS Region that the summary applies to.
final
resourceType → String?
The AWS resource type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetId → String?
The account identifier or the root identifier of the organization. If you don't know the root ID, you can call the AWS Organizations ListRoots API.
final
targetIdType → TargetIdType?
Whether the target is an account, an OU, or the organization root.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited